==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/blg_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['section_blog'] = 						"blog";
$lang['hdr_blog'] = 							"add or edit a blog";
$lang['hdr_group_blog'] = 						"add or edit a group blog for group 'GROUPTITLE'.";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_body'] = 							"details";
$lang['form_submit_save_go'] = 					"SAVE AND GO";
$lang['form_submit_save'] = 					"SAVE";
$lang['form_submit_preview'] = 					"preview";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_genre'] = 					"genre";
$lang['form_label_language'] = 					"language";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this blog";
$lang['form_just_me'] = 						"just me";
$lang['form_rsp_group'] = 						"Check to submit this to the web site editor for inclusion on the group home page.";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in Splash.";
$lang['form_rsp_group_auto'] = 					"Check to add this to the group home page.";
$lang['form_rsp_node_auto'] = 					"Check to add this to Splash.";


//ERRORS
$lang['err_blog_item_edit'] = 					"Sorry, you can only edit your blogs.";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Blog overview";
$lang['txt_overview_intro'] = 					"You can add a blog to this community. A blog is a short name for 'web log'. It is an Internet based diary. Add a small synopsis which is a one line description of the blog to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add your blog. If you are writing a long blog then save it every 10 minutes or so. That way if your Internet connection drops you do not loose everything.";
$lang['txt_header_3'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the blog on all lists. Choose one from the list below if desired.";
$lang['txt_header_4'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this blog to be published to.";
$lang['txt_header_5'] = 						"6. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_check_spelling'] = 					"check spelling";
$lang['txt_publish_level'] =					"everyone";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_public_help'] =				"Item will be submitted to web site editor and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your blog to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";



//$lang['hdr_images'] = 							"images";

?>

==> aroundme_0_6_0.tar.tgz: aroundme_0_6_0/aroundme/language/1/barnraiser_01/blg_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'blg_view.lang.php');

//HEADER
$lang['hdr_blog'] = 							"add or edit a blog";
$lang['hdr_group_blog'] = 						"add or edit a group blog";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_body'] = 							"details";
$lang['form_submit_preview'] = 					"preview";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_language'] = 					"language";
$lang['form_label_comments'] = 					"Allow comments";
$lang['form_just_me'] = 						"just me";
$lang['form_rsp_group'] = 						"Submit to group home page editor";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in the 'stuff' section";
$lang['form_rsp_group_auto'] = 					"Add to group home page";
$lang['form_rsp_node_auto'] = 					"Add to 'stuff' section";


//ERRORS
$lang['err_blog_item_edit'] = 					"Sorry, you can only edit your blogs.";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Blog overview";
$lang['txt_overview_intro'] = 					"You can add a blog to this community. A blog is a short name for 'web log'. It is an Internet based diary. Add a small synopsis which is a one line description of the blog to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add your blog. If you are writing a long blog then save it every 10 minutes or so. That way if your Internet connection drops you do not loose everything.";
$lang['txt_header_3'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the blog on all lists. Choose one from the list below if desired.";
$lang['txt_header_4'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this blog to be published to.";
$lang['txt_header_5'] = 						"6. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['sub_check_spelling'] = 					"check spelling";
$lang['txt_publish_help'] =						"How wide do you want the audience of your blog to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";

$lang['txt_publish_node_help'] =				"Submit to 'Stuff' editor";
$lang['txt_publish_auto_node_help'] = 			"Stuff";

$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"public web site";

?>
